{% extends 'layout.html' %}

{% block title %}{{ escape(page.title) }}{% end %}
{% block location %}{{ page.location }}-section{% end %}

{% block head %}
<script type="text/javascript">
(function() {
    var s = document.createElement('script'), t = document.getElementsByTagName('script')[0];
    s.type = 'text/javascript';
    s.async = true;
    s.src = 'http://api.flattr.com/js/0.6/load.js?mode=auto';
    t.parentNode.insertBefore(s, t);
})();
</script>
{% end %}

{% block content %}
  <article class="page">
    {{ page.content }}

    <p>How about a Flattr?</p>

    <p>
      <a class="FlattrButton" style="display:none;" href="http://misaka.61924.nl/"></a>
      <noscript>
        <a href="http://flattr.com/thing/683782/Misaka" target="_blank">
          <img src="http://api.flattr.com/button/flattr-badge-large.png" alt="Flattr this" title="Flattr this" />
        </a>
      </noscript>
    </p>
  </article>
{% end %}
